# Generated by Django 2.2.24 on 2021-10-29 13:53

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('edx_proctoring', '0020_auto_20211028_1915'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='proctoredexamsoftwaresecurereview',
            name='video_url',
        ),
        migrations.RemoveField(
            model_name='proctoredexamsoftwaresecurereviewhistory',
            name='video_url',
        ),
        migrations.AddField(
            model_name='proctoredexamsoftwaresecurereviewhistory',
            name='encrypted_video_url',
            field=models.BinaryField(null=True),
        ),
    ]
